@@ -1,5 +1,5 @@
+use html_editor::operation::*;
 use html_editor::parse;
-use html_editor::prelude::*;
 
 const HTML: &str = r#"
     <div>
